export class Vector2 {
  constructor(public x: number = 0, public y: number = 0) { }

  // 向量加法
  add(v: Vector2): Vector2 {
    return new Vector2(this.x + v.x, this.y + v.y);
  }

  // 向量减法
  subtract(v: Vector2): Vector2 {
    return new Vector2(this.x - v.x, this.y - v.y);
  }

  // 向量缩放
  scale(scalar: number): Vector2 {
    return new Vector2(this.x * scalar, this.y * scalar);
  }

  // 向量归一化
  normalize(): Vector2 {
    const len = this.length();
    return len > 0 ? this.scale(1 / len) : new Vector2();
  }

  // 向量长度
  length(): number {
    return Math.sqrt(this.x * this.x + this.y * this.y);
  }

  // 计算两点间距离
  distanceTo(v: Vector2): number {
    return this.subtract(v).length();
  }

  // 克隆向量
  clone(): Vector2 {
    return new Vector2(this.x, this.y);
  }

  // 限制向量长度
  clampLength(maxLength: number): Vector2 {
    const len = this.length();
    return len > maxLength ? this.normalize().scale(maxLength) : this.clone();
  }
}
